@@ -435,6 +435,20 @@ CREATE TABLE device_battery_event (
    */
   event_id uuid NOT NULL DEFAULT uuid_generate_v4(),
 
+  /**
+   * The identification of this event generated by the client application
+   * running on the mobile device that reported this event.
+   *
+   * This identification is used to detect events that the mobile device
+   * would report multiple times.  This happens when network outage occurs
+   * after the client application reported successfully a batch of events,
+   * but the network connection with the cloud service timed out before the
+   * client application had the chance to receive the acknowledgement from
+   * the cloud service.  Therefore, the client application reattempts to
+   * report one more time these events.
+   */
+  event_cid text NOT NULL,
+
   /**
    * The identification of the mobile device which battery state has
    * changed.
@@ -459,20 +473,6 @@ CREATE TABLE device_battery_event (
    */
   team_id uuid NULL,
 
-  /**
-   * The reference of this event as given by the client application running
-   * on the mobile device that reported this event.
-   *
-   * This information is used to detect events that the mobile device would
-   * report multiple times.  This happens when network outage occurs after
-   * the client application reported successfully a batch of events, but
-   * the network connection with the cloud service timed out before the
-   * client application had the chance to receive the acknowledgement from
-   * the cloud service.  Therefore, the client application reattempts to
-   * report one more time these events.
-   */
-  event_ref text NOT NULL,
-
   /**
    * The time when the mobile device detected the battery stats change.
    */
@@ -578,6 +578,12 @@ CREATE TABLE device_battery_event (
  * reliability and usability of a telecommunications service, and aims
  * to determine the geographical areas where the service coverage is the
  * best.
+ *
+ *
+ * @note: Keep-alive messages don't need the attribute 'client_cid' (an
+ *     identification that the client application would have generated)
+ *     since these messages are ephemeral.  Each message is sent once,
+ *     with no retry if the message would have been lost.
  */
 CREATE TABLE device_keepalive_event (
   /**
@@ -714,6 +720,20 @@ CREATE TABLE device_location_event (
    */
   event_id uuid NOT NULL DEFAULT uuid_generate_v4(),
 
+   /**
+   * The identification of this event generated by the client application
+   * running on the mobile device that reported this event.
+   *
+   * This identification is used to detect events that the mobile device
+   * would report multiple times.  This happens when network outage occurs
+   * after the client application reported successfully a batch of events,
+   * but the network connection with the cloud service timed out before the
+   * client application had the chance to receive the acknowledgement from
+   * the cloud service.  Therefore, the client application reattempts to
+   * report one more time these events.
+   */
+  event_cid text NOT NULL,
+
   /**
    * The identification of the mobile device that reported this location
    * update.
@@ -739,20 +759,6 @@ CREATE TABLE device_location_event (
    */
   team_id uuid NULL,
 
-   /**
-   * The reference of this event as given by the client application running
-   * on the mobile device that reported this event.
-   *
-   * This information is used to detect events that the mobile device would
-   * report multiple times.  This happens when network outage occurs after
-   * the client application reported successfully a batch of events, but
-   * the network connection with the cloud service timed out before the
-   * client application had the chance to receive the acknowledgement from
-   * the cloud service.  Therefore, the client application reattempts to
-   * report one more time these events.
-   */
-  event_ref text NOT NULL,
-
   /**
    * The time when the mobile device received a notification indicating
    * that the device location has changed.
